@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Colin Walters <walters@verbum.org>
  */
@@ -35,7 +33,7 @@
 #include "ostree-fetcher.h"
 #include "ostree-fetcher-util.h"
 #ifdef HAVE_LIBSOUP_CLIENT_CERTS
-#include "ostree-tls-cert-interaction.h"
+#include "ostree-tls-cert-interaction-private.h"
 #endif
 #include "ostree-enumtypes.h"
 #include "ostree.h"
@@ -183,7 +181,7 @@ static OstreeFetcherPendingURI *
 pending_uri_ref (OstreeFetcherPendingURI *pending)
 {
   gint refcount;
-  g_return_val_if_fail (pending != NULL, NULL);
+  g_assert (pending);
   refcount = g_atomic_int_add (&pending->ref_count, 1);
   g_assert (refcount > 0);
   return pending;
