@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Colin Walters <walters@verbum.org>
  */
@@ -465,13 +463,11 @@ ostree_mutable_tree_ensure_parent_dirs (OstreeMutableTree  *self,
   OstreeMutableTree *subdir = self; /* nofree */
   for (guint i = 0; i+1 < split_path->len; i++)
     {
-      OstreeMutableTree *next;
       const char *name = split_path->pdata[i];
-
       if (g_hash_table_lookup (subdir->files, name))
         return glnx_throw (error, "Can't replace file with directory: %s", name);
 
-      next = g_hash_table_lookup (subdir->subdirs, name);
+      OstreeMutableTree *next = g_hash_table_lookup (subdir->subdirs, name);
       if (!next)
         {
           invalidate_contents_checksum (subdir);
@@ -481,6 +477,9 @@ ostree_mutable_tree_ensure_parent_dirs (OstreeMutableTree  *self,
         }
 
       subdir = next;
+      g_assert (subdir);
+      if (!_ostree_mutable_tree_make_whole (subdir, NULL, error))
+        return FALSE;
     }
 
   if (out_parent)
@@ -582,11 +581,9 @@ ostree_mutable_tree_walk (OstreeMutableTree     *self,
     }
   else
     {
-      OstreeMutableTree *subdir;
       if (!_ostree_mutable_tree_make_whole (self, NULL, error))
         return FALSE;
-
-      subdir = g_hash_table_lookup (self->subdirs, split_path->pdata[start]);
+      OstreeMutableTree *subdir = g_hash_table_lookup (self->subdirs, split_path->pdata[start]);
       if (!subdir)
         return set_error_noent (error, (char*)split_path->pdata[start]);
 
@@ -681,3 +678,39 @@ ostree_mutable_tree_new_from_checksum (OstreeRepo *repo,
   out->metadata_checksum = g_strdup (metadata_checksum);
   return out;
 }
+
+/**
+ * ostree_mutable_tree_new_from_commit:
+ * @repo: The repo which contains the objects refered by the checksums.
+ * @rev: ref or SHA-256 checksum
+ *
+ * Creates a new OstreeMutableTree with the contents taken from the given commit.
+ * The data will be loaded from the repo lazily as needed.
+ *
+ * Returns: (transfer full): A new tree
+ * Since: 2021.5
+ */
+OstreeMutableTree *
+ostree_mutable_tree_new_from_commit (OstreeRepo *repo,
+                                     const char *rev,
+                                     GError    **error)
+{
+  g_autofree char *commit = NULL;
+  if (!ostree_repo_resolve_rev (repo, rev, FALSE, &commit, error))
+    return NULL;
+  g_autoptr(GVariant) commit_v = NULL;
+  if (!ostree_repo_load_commit (repo, commit, &commit_v, NULL, error))
+    return NULL;
+
+  g_autoptr(GVariant) contents_checksum_v = NULL;
+  g_autoptr(GVariant) metadata_checksum_v = NULL;
+  char contents_checksum[OSTREE_SHA256_STRING_LEN + 1];
+  char metadata_checksum[OSTREE_SHA256_STRING_LEN + 1];
+  g_variant_get_child (commit_v, 6, "@ay", &contents_checksum_v);
+  ostree_checksum_inplace_from_bytes (g_variant_get_data (contents_checksum_v),
+                                      contents_checksum);
+  g_variant_get_child (commit_v, 7, "@ay", &metadata_checksum_v);
+  ostree_checksum_inplace_from_bytes (g_variant_get_data (metadata_checksum_v),
+                                      metadata_checksum);
+  return ostree_mutable_tree_new_from_checksum (repo, contents_checksum, metadata_checksum);
+}
