@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -26,6 +24,14 @@
 
 G_BEGIN_DECLS
 
+/**
+ * OSTREE_PATH_BOOTED:
+ * Filesystem path that is created on an ostree-booted system.
+ *
+ * Since: 2022.2
+ */
+#define OSTREE_PATH_BOOTED "/run/ostree-booted"
+
 #define OSTREE_TYPE_SYSROOT ostree_sysroot_get_type()
 #define OSTREE_SYSROOT(obj) \
   (G_TYPE_CHECK_INSTANCE_CAST ((obj), OSTREE_TYPE_SYSROOT, OstreeSysroot))
@@ -85,6 +91,9 @@ GPtrArray *ostree_sysroot_get_deployments (OstreeSysroot  *self);
 _OSTREE_PUBLIC
 OstreeDeployment *ostree_sysroot_get_booted_deployment (OstreeSysroot *self);
 _OSTREE_PUBLIC
+OstreeDeployment *
+ostree_sysroot_require_booted_deployment (OstreeSysroot *self, GError **error);
+_OSTREE_PUBLIC
 OstreeDeployment *ostree_sysroot_get_staged_deployment (OstreeSysroot *self);
 
 _OSTREE_PUBLIC
@@ -186,6 +195,21 @@ gboolean ostree_sysroot_write_deployments_with_options (OstreeSysroot     *self,
                                                         GCancellable      *cancellable,
                                                         GError           **error);
 
+_OSTREE_PUBLIC
+gboolean ostree_sysroot_stage_overlay_initrd (OstreeSysroot  *self,
+                                              int             fd,
+                                              char          **out_checksum,
+                                              GCancellable   *cancellable,
+                                              GError        **error);
+
+typedef struct {
+  gboolean unused_bools[8];
+  int unused_ints[8];
+  char **override_kernel_argv;
+  char **overlay_initrds;
+  gpointer unused_ptrs[6];
+} OstreeSysrootDeployTreeOpts;
+
 _OSTREE_PUBLIC
 gboolean ostree_sysroot_deploy_tree (OstreeSysroot     *self,
                                      const char        *osname,
@@ -197,6 +221,17 @@ gboolean ostree_sysroot_deploy_tree (OstreeSysroot     *self,
                                      GCancellable      *cancellable,
                                      GError           **error);
 
+_OSTREE_PUBLIC
+gboolean ostree_sysroot_deploy_tree_with_options (OstreeSysroot     *self,
+                                                  const char        *osname,
+                                                  const char        *revision,
+                                                  GKeyFile          *origin,
+                                                  OstreeDeployment  *provided_merge_deployment,
+                                                  OstreeSysrootDeployTreeOpts *opts,
+                                                  OstreeDeployment **out_new_deployment,
+                                                  GCancellable      *cancellable,
+                                                  GError           **error);
+
 _OSTREE_PUBLIC
 gboolean ostree_sysroot_stage_tree (OstreeSysroot     *self,
                                     const char        *osname,
@@ -208,6 +243,18 @@ gboolean ostree_sysroot_stage_tree (OstreeSysroot     *self,
                                     GCancellable      *cancellable,
                                     GError           **error);
 
+_OSTREE_PUBLIC
+gboolean ostree_sysroot_stage_tree_with_options (OstreeSysroot     *self,
+                                                 const char        *osname,
+                                                 const char        *revision,
+                                                 GKeyFile          *origin,
+                                                 OstreeDeployment  *merge_deployment,
+                                                 OstreeSysrootDeployTreeOpts *opts,
+                                                 OstreeDeployment **out_new_deployment,
+                                                 GCancellable      *cancellable,
+                                                 GError           **error);
+
+
 _OSTREE_PUBLIC
 gboolean ostree_sysroot_deployment_set_mutable (OstreeSysroot     *self,
                                                 OstreeDeployment  *deployment,
