@@ -14,16 +14,16 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
 
 #include <ostree-async-progress.h>
+#include <ostree-content-writer.h>
 #include <ostree-core.h>
 #include <ostree-repo.h>
+#include <ostree-repo-os.h>
 #include <ostree-mutable-tree.h>
 #include <ostree-remote.h>
 #include <ostree-repo-file.h>
