@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -46,4 +44,11 @@ gpgme_data_t ot_gpgme_data_output (GOutputStream *output_stream);
 gpgme_ctx_t ot_gpgme_new_ctx (const char *homedir,
                               GError    **error);
 
+void ot_gpgme_kill_agent (const char *homedir);
+
+gboolean ot_gpg_wkd_urls (const char  *email,
+                          char       **out_advanced_url,
+                          char       **out_direct_url,
+                          GError     **error);
+
 G_END_DECLS
