@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Colin Walters <walters@verbum.org>
  */
@@ -459,5 +457,8 @@ ostree_builtin_fsck (int argc, char **argv, OstreeCommandInvocation *invocation,
   if (n_fsck_partial > 0)
     return glnx_throw (error, "%u partial commits from fsck-detected corruption", n_partial);
 
+  g_print ("object fsck of %d commits completed successfully - no errors found.\n", 
+           (guint)g_hash_table_size (commits));
+
   return TRUE;
 }
