@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Stef Walter <stefw@redhat.com>
  */
@@ -42,3 +40,6 @@ void   ot_dump_object     (OstreeObjectType   objtype,
 
 void   ot_dump_summary_bytes  (GBytes          *summary_bytes,
                                OstreeDumpFlags  flags);
+
+gboolean ot_dump_gpg_key  (GVariant  *key,
+                           GError   **error);
