@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Colin Walters <walters@verbum.org>
  */
@@ -25,6 +23,7 @@
 
 #include <gio/gio.h>
 
+#include <locale.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/statvfs.h>
@@ -42,6 +41,10 @@ static gboolean opt_verbose;
 static gboolean opt_version;
 static gboolean opt_print_current_dir;
 
+// TODO: make this public?  But no one sane wants to use our C headers
+// to find where to put files.  Maybe we can make it printed by the CLI?
+#define _OSTREE_EXT_DIR PKGLIBEXECDIR "/ext"
+
 static GOptionEntry global_entries[] = {
   { "verbose", 'v', 0, G_OPTION_ARG_NONE, &opt_verbose, "Print debug information during command processing", NULL },
   { "version", 0, 0, G_OPTION_ARG_NONE, &opt_version, "Print version information and exit", NULL },
@@ -117,7 +120,7 @@ maybe_setup_mount_namespace (gboolean    *out_ns,
     return TRUE;
 
   /* If the system isn't booted via libostree, also nothing to do */
-  if (!glnx_fstatat_allow_noent (AT_FDCWD, "/run/ostree-booted", NULL, 0, error))
+  if (!glnx_fstatat_allow_noent (AT_FDCWD, OSTREE_PATH_BOOTED, NULL, 0, error))
     return FALSE;
   if (errno == ENOENT)
     return TRUE;
@@ -142,13 +145,116 @@ message_handler (const gchar *log_domain,
     g_printerr ("%s: %s\n", g_get_prgname (), message);
 }
 
+int
+ostree_main (int    argc,
+             char **argv,
+             OstreeCommand *commands)
+{
+  g_autoptr(GError) error = NULL;
+
+  setlocale (LC_ALL, "");
+
+  g_set_prgname (argv[0]);
+
+  int ret = ostree_run (argc, argv, commands, &error);
+
+  if (error != NULL)
+    {
+      g_printerr ("%s%serror:%s%s %s\n",
+                  ot_get_red_start (), ot_get_bold_start (),
+                  ot_get_bold_end (), ot_get_red_end (),
+                  error->message);
+    }
+
+  return ret;
+}
+
+
+/**
+ * ostree_command_lookup_external:
+ * @argc: number of entries in @argv
+ * @argv: array of command-line arguments
+ * @commands: array of hardcoded internal commands
+ *
+ * Search for a relevant ostree extension binary in $PATH. Given a verb
+ * from argv, if it is not an internal command, it tries to locate a
+ * corresponding 'ostree-$verb' executable on the system.
+ *
+ * Returns: (transfer full) (nullable): callname (i.e. argv[0]) for the
+ * external command if found, or %NULL otherwise.
+ */
+gchar *
+ostree_command_lookup_external (int argc,
+                                char **argv,
+                                OstreeCommand *commands)
+{
+  g_assert (commands != NULL);
+
+  // Find the first verb (ignoring all earlier flags), then
+  // check if it is a known native command. Otherwise, try to look it
+  // up in /usr/lib/ostree/ostree-$cmd or $PATH.
+  // We ignore argv[0] here, the ostree binary itself is not multicall.
+  for (guint arg_index = 1; arg_index < argc; arg_index++)
+    {
+      char *current_arg = argv[arg_index];
+      if (current_arg == NULL ||
+          g_str_has_prefix (current_arg, "-") ||
+          g_strcmp0 (current_arg, "") == 0)
+          continue;
+
+      for (guint cmd_index = 0; commands[cmd_index].name != NULL; cmd_index++)
+        {
+          if (g_strcmp0 (current_arg, (commands[cmd_index]).name) == 0)
+            return NULL;
+        }
+
+
+      g_autofree gchar *ext_command = g_strdup_printf ("ostree-%s", current_arg);
+
+      /* First, search in our libdir /usr/lib/ostree/ostree-$cmd */
+      g_autofree char *ext_lib = g_strconcat (_OSTREE_EXT_DIR, "/", ext_command, NULL);
+      struct stat stbuf;
+      if (stat (ext_lib, &stbuf) == 0)
+        return g_steal_pointer (&ext_lib);
+
+      /* Otherwise, look in $PATH */
+      if (g_find_program_in_path (ext_command) == NULL)
+          return NULL;
+      return g_steal_pointer (&ext_command);
+    }
+
+  return NULL;
+}
+
+/**
+ * ostree_command_exec_external:
+ * @argv: array of command-line arguments
+ *
+ * Execute an ostree extension binary.
+ *
+ * Returns: diverge on proper execution, otherwise return 1.
+ */
+int
+ostree_command_exec_external (char **argv)
+{
+  int r = execvp(argv[0], argv);
+  g_assert (r == -1);
+
+  setlocale (LC_ALL, "");
+  g_printerr ("%s%serror:%s%s: Executing %s: %s\n",
+              ot_get_red_start (), ot_get_bold_start (),
+              ot_get_bold_end (), ot_get_red_end (),
+              argv[0],
+              g_strerror (errno));
+  return 1;
+}
+
 int
 ostree_run (int    argc,
             char **argv,
             OstreeCommand *commands,
             GError **res_error)
 {
-  OstreeCommand *command;
   GError *error = NULL;
   GCancellable *cancellable = NULL;
 #ifndef BUILDOPT_TSAN
@@ -159,7 +265,11 @@ ostree_run (int    argc,
   int in, out;
 
   /* avoid gvfs (http://bugzilla.gnome.org/show_bug.cgi?id=526454) */
-  g_setenv ("GIO_USE_VFS", "local", TRUE);
+  if (!g_setenv ("GIO_USE_VFS", "local", TRUE))
+    {
+      (void) glnx_throw (res_error, "Failed to set environment variable GIO_USE_FVS");
+      return 1;
+    }
 
   g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE, message_handler, NULL);
 
@@ -187,7 +297,7 @@ ostree_run (int    argc,
 
   argc = out;
 
-  command = commands;
+  OstreeCommand *command = commands;
   while (command->name)
     {
       if (g_strcmp0 (command_name, command->name) == 0)
@@ -239,7 +349,7 @@ ostree_run (int    argc,
   return 0;
 }
 
-/* Process a --repo arg; used below, and for the remote builtins */
+/* Process a --repo arg. */
 static OstreeRepo *
 parse_repo_option (GOptionContext *context,
                    const char     *repo_path,
@@ -249,19 +359,6 @@ parse_repo_option (GOptionContext *context,
 {
   g_autoptr(OstreeRepo) repo = NULL;
 
-  /* This is a bit of a brutal hack; we set up a mount
-   * namespace if it appears that we may need it.  It'd
-   * be better to do this more precisely in the future.
-   */
-  gboolean setup_ns = FALSE;
-  if (!maybe_setup_mount_namespace (&setup_ns, error))
-    return FALSE;
-  if (setup_ns)
-    {
-      if (mount ("/sysroot", "/sysroot", NULL, MS_REMOUNT | MS_SILENT, NULL) < 0)
-        return glnx_null_throw_errno_prefix (error, "Remounting /sysroot read-write");
-    }
-
   if (repo_path == NULL)
     {
       g_autoptr(GError) local_error = NULL;
@@ -301,6 +398,43 @@ parse_repo_option (GOptionContext *context,
   return g_steal_pointer (&repo);
 }
 
+/* Process a --repo arg, determining if we should remount /sysroot; used below, and for the remote builtins */
+static OstreeRepo *
+parse_repo_option_and_maybe_remount (GOptionContext *context,
+                                     const char     *repo_path,
+                                     gboolean        skip_repo_open,
+                                     GCancellable   *cancellable,
+                                     GError        **error)
+{
+  g_autoptr(OstreeRepo) repo = parse_repo_option (context, repo_path, skip_repo_open, cancellable, error);
+  if (!repo)
+    return NULL;
+
+  /* This is a bit of a brutal hack; we set up a mount
+   * namespace if it appears that we may need it.  It'd
+   * be better to do this more precisely in the future.
+   */
+  if (ostree_repo_is_system (repo) && !ostree_repo_is_writable (repo, NULL))
+    {
+      gboolean setup_ns = FALSE;
+      if (!maybe_setup_mount_namespace (&setup_ns, error))
+        return FALSE;
+      if (setup_ns)
+        {
+          if (mount ("/sysroot", "/sysroot", NULL, MS_REMOUNT | MS_SILENT, NULL) < 0)
+            return glnx_null_throw_errno_prefix (error, "Remounting /sysroot read-write");
+
+          /* Reload the repo so it's actually writable. */
+          g_clear_pointer (&repo, g_object_unref);
+          repo = parse_repo_option (context, repo_path, skip_repo_open, cancellable, error);
+          if (!repo)
+            return NULL;
+        }
+    }
+
+  return g_steal_pointer (&repo);
+}
+
 /* Used by the remote builtins which are special in taking --sysroot or --repo */
 gboolean
 ostree_parse_sysroot_or_repo_option (GOptionContext *context,
@@ -324,7 +458,7 @@ ostree_parse_sysroot_or_repo_option (GOptionContext *context,
     }
   else
     {
-      repo = parse_repo_option (context, repo_path, FALSE, cancellable, error);
+      repo = parse_repo_option_and_maybe_remount (context, repo_path, FALSE, cancellable, error);
       if (!repo)
         return FALSE;
     }
@@ -425,8 +559,8 @@ ostree_option_context_parse (GOptionContext *context,
 
   if (!(flags & OSTREE_BUILTIN_FLAG_NO_REPO))
     {
-      repo = parse_repo_option (context, opt_repo, (flags & OSTREE_BUILTIN_FLAG_NO_CHECK) > 0,
-                                cancellable, error);
+      repo = parse_repo_option_and_maybe_remount (context, opt_repo, (flags & OSTREE_BUILTIN_FLAG_NO_CHECK) > 0,
+                                                  cancellable, error);
       if (!repo)
         return FALSE;
     }
